==> haskell-http-conduit-2.3.9.1-125-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-conduit
version:              2.3.9.1
visibility:           public
id:                   http-conduit-2.3.9.1-ELIzfrfN67xHYB6OkkMeVz
key:                  http-conduit-2.3.9.1-ELIzfrfN67xHYB6OkkMeVz
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             https://github.com/snoyberg/http-client
synopsis:
    HTTP client package with conduit interface and HTTPS support.

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-conduit>.

category:             Web, Conduit
abi:                  ebc852e9a66ed9e3757d760676490cbe
exposed:              True
exposed-modules:
    Network.HTTP.Client.Conduit Network.HTTP.Conduit
    Network.HTTP.Simple

import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-conduit-2.3.9.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-conduit-2.3.9.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-conduit-2.3.9.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-conduit
hs-libraries:         HShttp-conduit-2.3.9.1-ELIzfrfN67xHYB6OkkMeVz
depends:
    aeson-2.1.2.1-2383fjET7FWJSHJW4VQuW
    attoparsec-0.14.4-H9Y4iLHDqcP1CPr5BByOUl
    attoparsec-aeson-2.1.0.0-JiHEPoU6Hkc7CxEyeQGu8D base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-KngnZK76tgfFFxoV5CBnAq
    conduit-extra-1.3.8-3MmKPDiWyuY7jVYKoSUOkF
    http-client-0.7.19-L1utxVEiLaAGw6Jin0pjGQ
    http-client-tls-0.3.6.4-GPXWf86JjcLLjWRBBwYJzj
    http-types-0.12.4-J468GPAKalzFHPyn7Dxh3c mtl-2.2.2
    resourcet-1.2.6-8KhhDEoJhCCBtuaTnBSqQF transformers-0.5.6.2
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:
    /usr/share/doc/haskell-http-conduit/html/http-conduit.haddock

haddock-html:         /usr/share/doc/haskell-http-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-conduit-2.3.9.1-126-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-conduit
version:              2.3.9.1
visibility:           public
id:                   http-conduit-2.3.9.1-KYb3AREOVb2COrnBIWmjoV
key:                  http-conduit-2.3.9.1-KYb3AREOVb2COrnBIWmjoV
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             https://github.com/snoyberg/http-client
synopsis:
    HTTP client package with conduit interface and HTTPS support.

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-conduit>.

category:             Web, Conduit
abi:                  4ebd811f3a3145192d390a28139d26ce
exposed:              True
exposed-modules:
    Network.HTTP.Client.Conduit Network.HTTP.Conduit
    Network.HTTP.Simple

import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-conduit-2.3.9.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-conduit-2.3.9.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-conduit-2.3.9.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-conduit
hs-libraries:         HShttp-conduit-2.3.9.1-KYb3AREOVb2COrnBIWmjoV
depends:
    aeson-2.1.2.1-BWqAP5DPS0iMNSAJtMWSf
    attoparsec-0.14.4-7XWZ3nsZOGKJDEorzXp6qF
    attoparsec-aeson-2.1.0.0-FXj7tOmtjxCJauw5Ev0wtT base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-FwwHGMHw6pcBHMWck7Ofs9
    conduit-extra-1.3.8-vK8Qg1gjQMD0RI2KcVvuH
    http-client-0.7.19-LKlU3HcOEMNION0MdQYtj
    http-client-tls-0.3.6.4-1iaAAi64BfdGALlJ7qoOys
    http-types-0.12.4-JotGc98QwUtHuX8PPdlxoe mtl-2.2.2
    resourcet-1.2.6-Jhk5QcgHinY7iAJawXyIYk transformers-0.5.6.2
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:
    /usr/share/doc/haskell-http-conduit/html/http-conduit.haddock

haddock-html:         /usr/share/doc/haskell-http-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
